# is-odd
A package to check if a number is odd or not

Installation:
```
python -m pip install is_odd
```

### Python version used
```
Python 3.7.5
```


## USAGE

```
import is_odd
r = is_odd.valid(23)
print(r)
r = is_odd.valid("352")
print(r)
```